@@ -27,7 +27,7 @@ from dataiter.list_of_dicts import ListOfDicts # noqa
 from dataiter.list_of_dicts import ObsoleteError # noqa
 from dataiter.list_of_dicts import ObsoleteListOfDicts # noqa
 
-__version__ = "0.10"
+__version__ = "0.13"
 
 DEFAULT_PEEK_ELEMENTS = 10
 DEFAULT_PEEK_ITEMS = 3
@@ -39,7 +39,19 @@ PRINT_MAX_ROWS = 100
 PRINT_MAX_WIDTH = 80
 
 def ncol(data):
+    """
+    Return the amount of columns in `data`.
+    """
     return data.ncol
 
 def nrow(data):
+    """
+    Return the amount of rows in `data`.
+
+    This is a useful shorthand for `data.nrow` in contexts where you don't have
+    direct access to the data frame in question, e.g. in group-by-aggregate
+
+    >>> data = di.DataFrame.read_csv("data/listings.csv")
+    >>> data.group_by("hood").aggregate(n=di.nrow)
+    """
     return data.nrow
